pm4py.algo.filtering.log.attributes package
===========================================

Submodules
----------

pm4py.algo.filtering.log.attributes.attributes\_filter module
-------------------------------------------------------------

.. automodule:: pm4py.algo.filtering.log.attributes.attributes_filter
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.algo.filtering.log.attributes
   :members:
   :undoc-members:
   :show-inheritance:
